==> library1.4.1.tar.bz2: library/books/rez_on_frm.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

 require_once "../utils/chlang.php";

  $title = $TEXT['book-rez'];
  $button = $TEXT['book-rez-on'];
  $action = "rez_on.php";
?>
<script type="text/javascript" language="JavaScript" src="../lang/<?php echo $lang; ?>/calendar.js"></script>
<?php
  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['book_id'])) {puterror($result2['skin'],$TEXT['error-book5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['book_id'])>20) {puterror($result2['skin'],$TEXT['error-book6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['book_id'] = rep($_GET['book_id']);

  $date_day = date("d");
  $date_month = date("m");
  $date_year = date("Y");
  $chislo = (date("$date_year\-$date_month\-$date_day"));

?>
<form name='book' enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it"><?php echo $TEXT['book-data5']; ?></td><td><input size=10 maxlength=10 type=text name=data_zakaza value='<?php echo $chislo; ?>' />
<script type="text/javascript" language="JavaScript">
	var o_cal = new tcal ({
		// form name
		'formname': 'book',
		// input name
		'controlname': 'data_zakaza'
	});
	</script></td></tr>
<tr><td class="bold_it"><?php echo $TEXT['user-tit']; ?></td><td>
    <select name="user_id">
    <?php
        $query10 = "SELECT login_id,  name, familiya, otchestvo FROM `tbl_logins` ORDER BY familiya ";
          $result10 = mysqli_query($dbcnx,$query10);
            if (!$result10) {puterror($result2['skin'],$TEXT['error-tbl7']); require_once "../utils/bottom_adm.php"; exit();}
              while($result_login = mysqli_fetch_array($result10))
                {
                    if($result_login['login_id'] == $result2['login_id']) {$chk_login = "<option selected value=".$result_login['login_id'].">".$result_login['familiya']."&nbsp;".$result_login['name']."&nbsp;".$result_login['otchestvo']."";}
                    else {$chk_login = "<option value=".$result_login['login_id'].">".$result_login['familiya']."&nbsp;".$result_login['name']."&nbsp;".$result_login['otchestvo']."";}
                 echo $chk_login;
                }
    ?>
    </select></td></tr>
<tr><td></td><td><input type=submit value='<?php echo $button; ?>' />
<input type=hidden name=book_id value='<?php echo $_GET['book_id']; ?>' />
</td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/books/rez_on_frm.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

 require_once "../utils/chlang.php";

  $title = $TEXT['book-rez'];
  $button = $TEXT['book-rez-on'];
  $action = "rez_on.php";
?>
<script type="text/javascript" language="JavaScript" src="../lang/<?php echo $lang; ?>/calendar.js"></script>
<?php
  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['book_id'])) {puterror($result2['skin'],$TEXT['error-book5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['book_id'])>20) {puterror($result2['skin'],$TEXT['error-book6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['book_id'] = rep($_GET['book_id']);

  $date_day = date("d");
  $date_month = date("m");
  $date_year = date("Y");
  $chislo = (date("$date_year\-$date_month\-$date_day"));

?>
<form name="book" enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center" >
    <tr><td class="bold_it"><?php echo $TEXT['book-data5']; ?></td><td><input size="10" maxlength="10" type="date" name="data_zakaza" value="<?php echo $chislo; ?>" />
<script type="text/javascript" language="JavaScript">
	var o_cal = new tcal ({
		// form name
		'formname': 'book',
		// input name
		'controlname': 'data_zakaza'
	});
	</script></td></tr>
<tr><td class="bold_it"><?php echo $TEXT['user-tit']; ?></td><td>
    <select name="user_id">
    <?php
        $query10 = "SELECT login_id, name, familiya, otchestvo FROM `tbl_logins` ORDER BY familiya ";
          $result10 = mysqli_query($dbcnx,$query10);
            if (!$result10) {puterror($result2['skin'],$TEXT['error-tbl7']); require_once "../utils/bottom_adm.php"; exit();}
              while($result_login = mysqli_fetch_array($result10))
                {
                    if($result_login['login_id'] == $result2['login_id']) {$chk_login = "<option selected value=".$result_login['login_id'].">".$result_login['familiya']."&nbsp;".$result_login['name']."&nbsp;".$result_login['otchestvo']."";}
                    else {$chk_login = "<option value=".$result_login['login_id'].">".$result_login['familiya']."&nbsp;".$result_login['name']."&nbsp;".$result_login['otchestvo']."";}
                 echo $chk_login;
                }
    ?>
    </select></td></tr>
<tr><td></td><td><input type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="book_id" value="<?php echo $_GET['book_id']; ?>" />
</td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
